@@ -5,12 +5,16 @@ module Treetop
         super
         
         builder.if__ "has_terminal?(#{grounded_regexp(text_value)}, true, index)" do
-          assign_result "instantiate_node(#{node_class_name},input, index...(index + 1))"
-          extend_result_with_inline_module
+          if address == 0 || decorated?
+            assign_result "instantiate_node(#{node_class_name},input, index...(index + 1))"
+            extend_result_with_inline_module
+          else
+            assign_lazily_instantiated_node
+          end
           builder << "@index += 1"
         end
         builder.else_ do
-          "terminal_parse_failure(#{single_quote(characters)})"
+          # "terminal_parse_failure(#{single_quote(characters)})"
           assign_result 'nil'
         end
       end
